#ifdef OPENGL_ES
#extension GL_OES_standard_derivatives : enable
#ifdef GL_FRAGMENT_PRECISION_HIGH
precision highp float;
#else
precision mediump float;
#endif
#else
precision mediump float;
#endif

// Uniforms
uniform sampler2D u_texture;
uniform float u_time;
uniform vec3 u_resolution;

// Varyings
varying vec2 v_texCoord;

float rand(vec2 p)
{
	float t = floor(u_time * 20.0) / 10.0;
	return fract(sin(dot(p, vec2(t * 12.9898, t * 78.233))) * 43758.5453);
}

float noise(vec2 uv, float blockiness)
{
	vec2 lv = fract(uv);
	vec2 id = floor(uv);

	float n1 = rand(id);
	float n2 = rand(id + vec2(1.0, 0.0));
	float n3 = rand(id + vec2(0.0, 1.0));
	float n4 = rand(id + vec2(1.0, 1.0));

	vec2 u = smoothstep(0.0, 1.0 + blockiness, lv);

	return mix(mix(n1, n2, u.x), mix(n3, n4, u.x), u.y);
}

float fbm(vec2 uv, int count, float blockiness, float complexity)
{
	float val = 0.0;
	float amp = 0.5;

	while(count != 0) {
		val += amp * noise(uv, blockiness);
		amp *= 0.5;
		uv *= complexity;
		count--;
	}

	return val;
}

const float glitchAmplitude = 0.2; // increase this
const float glitchNarrowness = 4.0;
const float glitchBlockiness = 2.0;
const float glitchMinimizer = 8.0; // decrease this

void main()
{

	vec2 uv = gl_FragCoord.xy / u_resolution.xy;
	float as = u_resolution.x / u_resolution.y;
	vec2 a = vec2(uv.x * as, uv.y);
	vec2 uv2 = vec2(a.x / u_resolution.x, exp(a.y));

	float sf = glitchAmplitude * pow(fbm(uv2, 4, glitchBlockiness, glitchNarrowness), glitchMinimizer);

	float cr = texture2D(u_texture, vec2(uv.x + sf, uv.y)).r * (1.0 - sf);
	float cg = texture2D(u_texture, vec2(uv.x - sf, uv.y)).g * (1.0 - sf);
	float cb = texture2D(u_texture, vec2(uv.x + sf, uv.y)).b * (1.0 - sf);
	vec3 c = vec3(cr, cg, cb);

	gl_FragColor = vec4(c, 1.0);
}
